@@ -13,15 +13,14 @@ describe 'octavia::api' do
       :allow_tls_terminated_listeners => false,
       :default_provider_driver        => 'ovn',
       :provider_drivers               => { 'amphora' => 'Octavia Amphora Driver', 'ovn' => 'Octavia OVN driver' },
-      :ovn_nb_connection              => 'tcp:127.0.0.1:6641'
     }
   end
 
   shared_examples_for 'octavia-api' do
     let :pre_condition do
       "class { 'octavia': }
-       include ::octavia::db
-       class { '::octavia::keystone::authtoken':
+       include octavia::db
+       class { 'octavia::keystone::authtoken':
          password  => 'password',
        }
       "
@@ -54,7 +53,6 @@ describe 'octavia::api' do
         is_expected.to contain_octavia_config('api_settings/allow_tls_terminated_listeners').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('api_settings/default_provider_driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('api_settings/enabled_provider_drivers').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_octavia_config('ovn/ovn_nb_connection').with_value('<SERVICE DEFAULT>')
       end
       it 'does not sync the database' do
         is_expected.not_to contain_class('octavia::db::sync')
@@ -70,7 +68,6 @@ describe 'octavia::api' do
       is_expected.to contain_octavia_config('api_settings/allow_tls_terminated_listeners').with_value( params[:allow_tls_terminated_listeners] )
       is_expected.to contain_octavia_config('api_settings/default_provider_driver').with_value( params[:default_provider_driver] )
       is_expected.to contain_octavia_config('api_settings/enabled_provider_drivers').with_value( params[:provider_drivers] )
-      is_expected.to contain_octavia_config('ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -119,11 +116,11 @@ describe 'octavia::api' do
   shared_examples 'octavia-api wsgi' do
     let :pre_condition do
       "class { 'octavia': }
-       include ::octavia::db
-       class { '::octavia::keystone::authtoken':
+       include octavia::db
+       class { 'octavia::keystone::authtoken':
          password  => 'password',
        }
-       include ::apache
+       include apache
       "
     end
 
